@@ -8,7 +8,7 @@ from minio import error as merr
 from minio_storage.errors import minio_error
 
 if T.TYPE_CHECKING:
-    from minio_storage.storage import Storage
+    from minio_storage.storage import MinioStorage
 
 logger = getLogger("minio_storage")
 
@@ -36,8 +36,8 @@ class NonSeekableMixin:
 
 
 class MinioStorageFile(File):
-    def __init__(self, name: str, mode: str, storage: "Storage", **kwargs):
-        self._storage: "Storage" = storage
+    def __init__(self, name: str, mode: str, storage: "MinioStorage", **kwargs):
+        self._storage: "MinioStorage" = storage
         self.name: str = name
         self._mode: str = mode
         self._file = None
@@ -46,15 +46,13 @@ class MinioStorageFile(File):
 class ReadOnlyMinioObjectFile(MinioStorageFile, ReadOnlyMixin, NonSeekableMixin):
     """A django File class which directly exposes the underlying minio object. This
     means the the instance doesnt support functions like .seek() and is required to
-    be closed to be able to reuse minio connections.
-
-    Note: This file class is not tested yet"""
+    be closed to be able to reuse minio connections."""
 
     def __init__(
         self,
         name: str,
         mode: str,
-        storage: "Storage",
+        storage: "MinioStorage",
         max_memory_size: T.Optional[int] = None,
         **kwargs,
     ):
@@ -66,7 +64,9 @@ class ReadOnlyMinioObjectFile(MinioStorageFile, ReadOnlyMixin, NonSeekableMixin)
             self.max_memory_size = max_memory_size
         super().__init__(name, mode, storage)
 
-    def _get_file(self):
+    @property
+    def file(self):
+        obj = None
         if self._file is None:
             try:
                 obj = self._storage.client.get_object(
@@ -74,21 +74,21 @@ class ReadOnlyMinioObjectFile(MinioStorageFile, ReadOnlyMixin, NonSeekableMixin)
                 )
                 self._file = obj
                 return self._file
-            except merr.ResponseError as error:
+            except merr.InvalidResponseError as error:
                 logger.warn(error)
-                raise OSError(f"File {self.name} does not exist")
+                raise OSError(f"File {self.name} does not exist") from error
             finally:
                 try:
-                    obj.release_conn()
+                    if obj:
+                        obj.release_conn()
                 except Exception as e:
                     logger.error(str(e))
         return self._file
 
+    @file.setter
     def _set_file(self, value):
         self._file = value
 
-    file = property(_get_file, _set_file)
-
     def close(self):
         try:
             self.file.close()
@@ -100,13 +100,13 @@ class ReadOnlySpooledTemporaryFile(MinioStorageFile, ReadOnlyMixin):
     """A django File class which buffers the minio object into a local
     SpooledTemporaryFile."""
 
-    max_memory_size: int = 1024 * 1024 * 10
+    max_memory_size: int = 10 * 1024 * 1024
 
     def __init__(
         self,
         name: str,
         mode: str,
-        storage: "Storage",
+        storage: "MinioStorage",
         max_memory_size: T.Optional[int] = None,
         **kwargs,
     ):
@@ -118,8 +118,10 @@ class ReadOnlySpooledTemporaryFile(MinioStorageFile, ReadOnlyMixin):
             self.max_memory_size = max_memory_size
         super().__init__(name, mode, storage)
 
-    def _get_file(self):
+    @property
+    def file(self):
         if self._file is None:
+            obj = None
             try:
                 obj = self._storage.client.get_object(
                     self._storage.bucket_name, self.name
@@ -131,20 +133,20 @@ class ReadOnlySpooledTemporaryFile(MinioStorageFile, ReadOnlyMixin):
                     self._file.write(d)
                 self._file.seek(0)
                 return self._file
-            except merr.ResponseError as error:
-                raise minio_error(f"File {self.name} does not exist", error)
+            except merr.InvalidResponseError as error:
+                raise minio_error(f"File {self.name} does not exist", error) from error
             finally:
                 try:
-                    obj.release_conn()
+                    if obj:
+                        obj.release_conn()
                 except Exception as e:
                     logger.error(str(e))
         return self._file
 
+    @file.setter
     def _set_file(self, value):
         self._file = value
 
-    file = property(_get_file, _set_file)
-
     def close(self):
         if self._file is not None:
             self._file.close()
