@@ -1,6 +1,6 @@
-import argparse
 import json
 import sys
+import typing as T
 from string import Template
 from unittest.mock import patch
 
@@ -24,7 +24,6 @@ class Command(BaseCommand):
     FULL_FORMAT = "$name $size $modified $url $etag"
 
     def add_arguments(self, parser):
-
         group = parser.add_argument_group("minio")
         group.add_argument(
             "--class",
@@ -46,12 +45,8 @@ class Command(BaseCommand):
             description="valid subcommands",
             # required=True,
         )
-        cmds._parser_class = argparse.ArgumentParser  # circumvent Django 1.11 bug
-
         cmds.add_parser(self.CHECK, help="check bucket")
-
         cmds.add_parser(self.CREATE, help="make bucket")
-
         cmds.add_parser(self.DELETE, help="remove an empty bucket")
 
         ls = cmds.add_parser(self.LIST, help="list bucket objects or buckets")
@@ -134,14 +129,14 @@ class Command(BaseCommand):
 
         try:
             storage_class = import_string(class_name)
-        except ImportError:
-            raise CommandError(f"could not find storage class: {class_name}")
+        except ImportError as err:
+            raise CommandError(f"could not find storage class: {class_name}") from err
         if not issubclass(storage_class, MinioStorage):
             raise CommandError(f"{class_name} is not an sub class of MinioStorage.")
 
         # TODO: maybe another way
         with patch.object(storage_class, "_init_check", return_value=None):
-            storage = storage_class()
+            storage = storage_class()  # type: ignore
             return storage
 
     def bucket_exists(self, storage, bucket_name):
@@ -163,11 +158,11 @@ class Command(BaseCommand):
         list_dirs: bool,
         list_files: bool,
         recursive: bool,
-        format: str = None,
+        format: T.Optional[str] = None,
         summary: bool = True,
     ):
         try:
-            objs = storage.client.list_objects_v2(
+            objs = storage.client.list_objects(
                 bucket_name, prefix=prefix, recursive=recursive
             )
 
@@ -200,24 +195,25 @@ class Command(BaseCommand):
 
             if summary:
                 print(f"{n_files} files and {n_dirs} directories", file=sys.stderr)
-        except minio.error.NoSuchBucket:
-            raise CommandError(f"bucket {bucket_name} does not exist")
+        except minio.error.S3Error as e:
+            raise CommandError(f"error reading bucket {bucket_name}") from e
 
     def bucket_create(self, storage, bucket_name):
         try:
             storage.client.make_bucket(bucket_name)
             print(f"created bucket: {bucket_name}", file=sys.stderr)
-        except minio.error.BucketAlreadyOwnedByYou:
-            raise CommandError(f"you have already created {bucket_name}")
+        except minio.error.S3Error as e:
+            raise CommandError(f"error creating {bucket_name}") from e
         return
 
     def bucket_delete(self, storage, bucket_name):
         try:
             storage.client.remove_bucket(bucket_name)
-        except minio.error.NoSuchBucket:
-            raise CommandError(f"bucket {bucket_name} does not exist")
-        except minio.error.BucketNotEmpty:
-            raise CommandError(f"bucket {bucket_name} is not empty")
+        except minio.error.S3Error as err:
+            if err.code == "BucketNotEmpty":
+                raise CommandError(f"bucket {bucket_name} is not empty") from err
+            elif err.code == "NoSuchBucket":
+                raise CommandError(f"bucket {bucket_name} does not exist") from err
 
     def policy_get(self, storage, bucket_name):
         try:
@@ -225,14 +221,15 @@ class Command(BaseCommand):
             policy = json.loads(policy)
             policy = json.dumps(policy, ensure_ascii=False, indent=2)
             return policy
-        except minio.error.NoSuchBucket:
-            raise CommandError(f"bucket {bucket_name} does not exist")
-        except minio.error.NoSuchBucketPolicy:
-            raise CommandError(f"bucket {bucket_name} has no policy")
+        except minio.error.S3Error as err:
+            if err.code == "NoSuchBucket":
+                raise CommandError(f"bucket {bucket_name} does not exist") from err
+            elif err.code == "NoSuchBucketPolicy":
+                raise CommandError(f"bucket {bucket_name} has no policy") from err
 
     def policy_set(self, storage, bucket_name, policy: Policy):
         try:
             policy = Policy(policy)
             storage.client.set_bucket_policy(bucket_name, policy.bucket(bucket_name))
-        except minio.error.NoSuchBucket as e:
-            raise CommandError(e.message)
+        except minio.error.S3Error as e:
+            raise CommandError(e.message) from e
