@@ -20,7 +20,6 @@ class CommandsTests(BaseTestMixin, TestCase):
         MINIO_STORAGE_AUTO_CREATE_MEDIA_POLICY=False,
     )
     def test_management_command(self):
-
         storage = self.media_storage
         bucket = self.media_storage.bucket_name
 
@@ -31,7 +30,7 @@ class CommandsTests(BaseTestMixin, TestCase):
 
         try:
             self.obliterate_bucket(self.media_storage.bucket_name)
-        except minio.error.NoSuchBucket:
+        except minio.error.S3Error:
             pass
 
         with self.assertRaisesRegex(CommandError, f"bucket {bucket} does not exist"):
@@ -40,7 +39,7 @@ class CommandsTests(BaseTestMixin, TestCase):
         with self.assertRaisesRegex(CommandError, f"bucket {bucket} does not exist"):
             call_command("minio", "policy")
 
-        with self.assertRaisesRegex(CommandError, f"bucket {bucket} does not exist"):
+        with self.assertRaisesRegex(CommandError, f"error reading bucket {bucket}"):
             call_command("minio", "ls")
 
         with self.assertRaisesRegex(CommandError, f"bucket {bucket} does not exist"):
@@ -50,7 +49,7 @@ class CommandsTests(BaseTestMixin, TestCase):
 
         call_command("minio", "check")
 
-        with self.assertRaisesRegex(CommandError, f"you have already created {bucket}"):
+        with self.assertRaisesRegex(CommandError, f"error creating {bucket}"):
             call_command("minio", "create")
 
         with self.assertRaisesRegex(CommandError, f"bucket {bucket} has no policy"):
