@@ -4,7 +4,7 @@ import requests
 from django.conf import settings
 from django.core.files.base import ContentFile, File
 from django.test import TestCase, override_settings
-from minio.error import InvalidAccessKeyId
+from minio.error import S3Error
 
 from minio_storage.storage import MinioMediaStorage
 
@@ -22,7 +22,7 @@ class UploadTests(BaseTestMixin, TestCase):
         MINIO_STORAGE_ACCESS_KEY="wrong_key", MINIO_STORAGE_SECRET_KEY="wrong_secret"
     )
     def test_file_upload_fail_incorrect_keys(self):
-        with self.assertRaises(InvalidAccessKeyId):
+        with self.assertRaises(S3Error):
             MinioMediaStorage()
 
     def test_two_files_with_the_same_name_can_be_uploaded(self):
@@ -66,15 +66,6 @@ class UploadTests(BaseTestMixin, TestCase):
     def test_upload_and_get_back_file_with_funky_name(self):
         self.media_storage.save("áčďěščřžýŽŇůúť.txt", ContentFile(b"12345"))
 
-    def test_uploaded_and_downloaded_file_sizes_match(self):
-        pass
-
-    def test_uploaded_files_end_up_in_the_right_bucket(self):
-        pass
-
-    def test_static_files_end_up_in_the_right_bucket(self):
-        pass
-
     def test_upload_file_beggining_with_dot(self):
         self.media_storage.save(
             ".hidden_file", ContentFile(b"Not really, but whatever")
@@ -88,7 +79,20 @@ class UploadTests(BaseTestMixin, TestCase):
         res = self.media_storage.client.stat_object(
             self.media_storage.bucket_name, ivan
         )
-        self.assertEqual(res.metadata, {"Content-Type": "text/plain"})
+        metadata_attrs = {
+            "Accept-Ranges",
+            "Content-Length",
+            "Content-Security-Policy",
+            "Content-Type",
+            "ETag",
+            "Last-Modified",
+            "Server",
+            "Vary",
+            "X-Amz-Request-Id",
+            "X-Xss-Protection",
+            "Date",
+        }
+        self.assertTrue(metadata_attrs.issubset(res.metadata.keys()))  # type: ignore
 
 
 @override_settings(
@@ -100,7 +104,5 @@ class TestDefaultObjectMetadata(BaseTestMixin, TestCase):
         res = self.media_storage.client.stat_object(
             self.media_storage.bucket_name, ivan
         )
-        self.assertEqual(
-            res.metadata,
-            {"Cache-Control": "max-age=1000", "Content-Type": "text/plain"},
-        )
+
+        self.assertEqual(res.metadata["Cache-Control"], "max-age=1000")  # type: ignore
